@@ -22,7 +22,7 @@ class CSVImportAdmin(ModelAdmin):
         "import_user",
     ]
     formfield_overrides = {
-        models.CharField: {"widget": forms.Textarea(attrs={"rows": "4", "cols": "60"})},
+        models.CharField: {"widget": forms.Textarea(attrs={"rows": "1", "cols": "40"})},
     }
 
     def save_model(self, request, obj, form, change):
@@ -35,7 +35,6 @@ class CSVImportAdmin(ModelAdmin):
         cmd = Command()
         if obj.upload_file:
             obj.file_name = obj.upload_file.name
-            obj.encoding = ""
             defaults = self.filename_defaults(obj.file_name)
             cmd.setup(
                 mappings=obj.field_list,
@@ -62,3 +61,6 @@ class CSVImportAdmin(ModelAdmin):
 
 
 admin.site.register(CSVImport, CSVImportAdmin)
+from csvimport.tests.models import Item
+
+admin.site.register(Item)
