@@ -3,6 +3,7 @@
 """
 import time
 
+
 def _isdst(self, dt):
     """ Monkeypatch from https://code.djangoproject.com/ticket/3418
         since sqlite and other backends still have this issue in django 1.6
@@ -19,12 +20,13 @@ def _isdst(self, dt):
         return tt.tm_isdst > 0
     except OverflowError:
         pass
-    raise Exception('Cannot process dates from %s' % year)
+    raise Exception("Cannot process dates from %s" % year)
+
 
 try:
     from django.utils.timezone import ReferenceLocalTimezone
+
     ReferenceLocalTimezone._isdst = _isdst
 except:
     # Don't patch it if it isnt there to be patched!
     pass
-
