@@ -73,6 +73,7 @@ class CSVParser(object):
         # so reopen as raw unencoded and just try and get lines out one by one
         output = []
         count = 0
+        # TODO: Fix use of a quoted field with commas next to escaped quotes - eg. "field1=SOAP, ""200 g"", bar","field2"
         expression = r"""(['"]*)(.*?)\1(""" + delimiter + r"""|$)"""
         csvsplit = re.compile(expression)
         if not rows:
@@ -106,19 +107,11 @@ class CSVParser(object):
                 if pyversion == 3:
                     row = row.decode(self.charset)
                 if type(row) in self.string_types:
-                    # FIXME: Works for test fixtures - but rather hacky csvreader replacement regex splitter
-                    # breaks unless empty cols have a space added!
-                    row = row.replace(",,", ", ,")
-                    row = row.replace('""', '" "')
-                    row = row.replace("''", "' '")
                     if not row:
                         continue
-                    row = csvsplit.split(row)
-                    row = [
-                        item
-                        for item in row
-                        if item and item not in (delimiter, '"', "'")
-                    ]
+                    matches = csvsplit.findall(row)
+                    # Fix CSV repeat quote used for escaping within quotes
+                    row = [match[1].replace('""', '"') for match in matches][:-1]
                     if pyversion == 2:
                         try:
                             row = [unicode(item, self.charset) for item in row]
