@@ -4,6 +4,7 @@ from csvimport.tests.testcase import CommandTestCase
 from csvimport.tests.models import Country
 import sys
 from django.core.exceptions import ObjectDoesNotExist
+import django
 
 
 class ConstraintTest(CommandTestCase):
@@ -23,10 +24,14 @@ class ConstraintTest(CommandTestCase):
         """ Use custom command to upload a country file with missing long lat data"""
         errs = [
             "Field 'latitude' expected a number but got 'null'.",
+            "could not convert string to float: 'null'",
             "Field 'latitude' expected a number but got 'null'.",
+            "could not convert string to float: 'null'",
             "Imported 3 rows to Country",
         ]
-
+        if django.VERSION[0] == 2:
+            errs.append("could not convert string to float: 'null'")
+            errs.append("could not convert string to float: 'null'")
         self.command(
             csvfile=filename,
             modelname="csvimport.Country",
